@@ -7,6 +7,7 @@ extern "C" {
 
 #include <zlib.h>
 #include <Rdefines.h>
+#include "S4Vectors_interface.h"
 #include "IRanges_interface.h"
 #include "XVector_interface.h"
 #include "Biostrings_interface.h"
@@ -31,8 +32,8 @@ extern "C" {
     int _mark_field_0(char *, char **, const int);
 
     extern const int LINEBUF_SIZE;
-    gzFile *_fopen(const char *, const char *);
-    int _linebuf_skip_p(char *, gzFile *, const char *, int, const char *);
+    gzFile _fopen(const char *, const char *);
+    int _linebuf_skip_p(char *, gzFile, const char *, int, const char *);
 
     int _rtrim(char *linebuf);
     void _solexa_to_IUPAC(char *linebuf);
@@ -85,11 +86,6 @@ extern "C" {
 
     SEXP read_maq_map(SEXP filename, SEXP maxreads, SEXP maq_longread);
 
-/* pileup.c */
-
-    SEXP pileup(SEXP start, SEXP fraglength, SEXP chrlength, SEXP dir,
-                SEXP readlength, SEXP offset);
-
 /* readBfaToc.c */
 
     SEXP readBfaToc(SEXP bfa_filename);
