@@ -2,7 +2,6 @@
 #include <Rmath.h>
 #include <R_ext/Random.h>
 #include "ShortRead.h"
-#include "IRanges_interface.h"
 
 struct bufnode {
     int len;
@@ -74,6 +73,7 @@ const Rbyte *_fastq_record_end(const Rbyte * buf, const Rbyte * bufend)
 
 SEXP _fastq_as_XStringSet(struct records *fastq)
 {
+    static int init = 0;
     SEXP widths = PROTECT(NEW_LIST(2));
     SET_VECTOR_ELT(widths, 0, NEW_INTEGER(fastq->n_curr));
     SET_VECTOR_ELT(widths, 1, NEW_INTEGER(fastq->n_curr));
@@ -118,6 +118,13 @@ SEXP _fastq_as_XStringSet(struct records *fastq)
         qual = hold_XVectorList(VECTOR_ELT(ans, 1)),
         id = hold_XVectorList(VECTOR_ELT(ans, 2));
 
+    if ((!init) && fastq->n_curr) {
+        /* hack -- install symbols to avoid stack imbalance */
+        (void) get_elt_from_XRawList_holder(&id, 0);
+        (void) DNAencode('A');
+        init = 1;
+    }
+
 #ifdef SUPPORT_OPENMP
 #pragma omp parallel for
 #endif
@@ -134,12 +141,12 @@ SEXP _fastq_as_XStringSet(struct records *fastq)
         while (!((*buf == '\n') || (*buf == '\r')))
             ++buf;
         x = get_elt_from_XRawList_holder(&id, i);
-        memcpy((char *) x.seq, start, (buf - start) * sizeof(Rbyte));
+        memcpy((char *) x.ptr, start, (buf - start) * sizeof(Rbyte));
 
         /* read */
         while ((*buf == '\n') || (*buf == '\r'))
             ++buf;
-        curr = (char *) get_elt_from_XRawList_holder(&sread, i).seq;
+        curr = (char *) get_elt_from_XRawList_holder(&sread, i).ptr;
         while (*buf != '+') {
             while (!((*buf == '\n') || (*buf == '\r'))) /* strip '\n' */
                 *curr++ = DNAencode(*buf++);
@@ -155,8 +162,8 @@ SEXP _fastq_as_XStringSet(struct records *fastq)
             ++buf;              /* leading '\n' */
         start = buf;
         x = get_elt_from_XRawList_holder(&qual, i);
-        curr = (char *) x.seq;
-        while (buf != bufend && curr - x.seq != x.length) {
+        curr = (char *) x.ptr;
+        while (buf != bufend && curr - x.ptr != x.length) {
             if ((*buf != '\n') && (*buf != '\r'))
                 *curr++ = *buf++;
             else
@@ -331,10 +338,10 @@ void _sampler_finalize(SEXP s)
 SEXP sampler_new(SEXP n)
 {
     struct sampler *sampler = _sampler_new(INTEGER(n)[0]);
-    SEXP s = PROTECT(R_MakeExternalPtr(sampler, mkString("sampler"),
+    SEXP s = PROTECT(R_MakeExternalPtr(sampler, PROTECT(mkString("sampler")),
                                        R_NilValue));
     R_RegisterCFinalizerEx(s, _sampler_finalize, TRUE);
-    UNPROTECT(1);
+    UNPROTECT(2);
     return s;
 }
 
@@ -477,10 +484,10 @@ void _streamer_finalize(SEXP s)
 SEXP streamer_new(SEXP n)
 {
     struct streamer *streamer = _streamer_new(INTEGER(n)[0]);
-    SEXP s = PROTECT(R_MakeExternalPtr(streamer, mkString("streamer"),
+    SEXP s = PROTECT(R_MakeExternalPtr(streamer, PROTECT(mkString("streamer")),
                                        R_NilValue));
     R_RegisterCFinalizerEx(s, _streamer_finalize, TRUE);
-    UNPROTECT(1);
+    UNPROTECT(2);
     return s;
 }
 
