@@ -70,10 +70,10 @@ ENCODE_FUNC encoder(const char *base)
 SEXP _get_namespace(const char *pkg)
 {
     SEXP fun = PROTECT(findFun(install("getNamespace"), R_GlobalEnv));
-    SEXP nmspc = PROTECT(NEW_CHARACTER(1));
-    SET_STRING_ELT(nmspc, 0, mkChar(pkg));
-    nmspc = eval(lang2(fun, nmspc), R_GlobalEnv);
-    UNPROTECT(2);
+    SEXP nmspc = PROTECT(mkString(pkg));
+    SEXP lng2 = PROTECT(lang2(fun, nmspc));
+    nmspc = eval(lng2, R_GlobalEnv);
+    UNPROTECT(3);
     return nmspc;
 }
 
@@ -114,8 +114,9 @@ int _char_as_strand_int(const char c, const char *fname, const int lineno)
 SEXP _get_SEXP(SEXP from, SEXP rho, const char *with)
 {
     SEXP fun = PROTECT(findFun(install(with), rho));
-    SEXP res = eval(lang2(fun, from), rho);
-    UNPROTECT(1);
+    SEXP lng2 = PROTECT(lang2(fun, from));
+    SEXP res = eval(lng2, rho);
+    UNPROTECT(2);
     return res;
 }
 
@@ -161,7 +162,7 @@ char *_mark_field_1(char *curr, const char *delim)
 
 char *_mark_field_n(char *curr, const char *delim)
 {
-    const char *d = '\0';
+    const char *d = NULL;
     while (*curr != '\0' && *curr != '\n') {
         d = delim;
         while (*d != '\0' && *d != *curr)
@@ -173,9 +174,9 @@ char *_mark_field_n(char *curr, const char *delim)
     }
     if (*curr == '\n') {
         *curr = '\0';
-        return '\0';
+        return NULL;
     }
-    return *d == '\0' ? '\0' : curr + 1;
+    return ((d == NULL) || (*d == '\0')) ? NULL : curr + 1;
 }
 
 SEXP _mark_field_test(SEXP filename, SEXP delimiters, SEXP dim)
@@ -213,6 +214,7 @@ SEXP _mark_field_test(SEXP filename, SEXP delimiters, SEXP dim)
             curr = next;
         }
     }
+    fclose(file);
 #undef LINEBUF_SIZE
 
     UNPROTECT(1);
@@ -224,9 +226,9 @@ const int LINEBUF_SIZE = 200001;
 /*
  * open and check file; signal error
  */
-gzFile *_fopen(const char *fname, const char *mode)
+gzFile _fopen(const char *fname, const char *mode)
 {
-    gzFile *file = gzopen(fname, mode);
+    gzFile file = gzopen(fname, mode);
     if (file == NULL)
         error("cannot open file %s", fname);
     return file;
@@ -235,7 +237,7 @@ gzFile *_fopen(const char *fname, const char *mode)
 /*
  * trim & check linebuf, return 0 if processing should continue
  */
-int _linebuf_skip_p(char *linebuf, gzFile * file, const char *fname, int lineno,
+int _linebuf_skip_p(char *linebuf, gzFile file, const char *fname, int lineno,
                     const char *commentChar)
 {
     int nchar_in_buf;
@@ -339,7 +341,7 @@ void _as_factor(SEXP vec, const char **levels, const int n_lvls)
  * file: an open file stream at position 0
  *
  */
-static int _count_lines(gzFile * file)
+static int _count_lines(gzFile file)
 {
     const int LINEBUF_SIZE = 20001;
     size_t bytes_read;
@@ -369,7 +371,7 @@ SEXP count_lines(SEXP files)
 {
     int i, nfile;
     const char *filepath;
-    gzFile *file;
+    gzFile file;
     SEXP ans = R_NilValue;
 
     if (!IS_CHARACTER(files))
